@@ -8,7 +8,8 @@ from typer import Typer
 
 app = Typer(
     help="Tool to handle a large number of beamer decks, "
-    "used by several persons, with shared slides amongst the decks."
+    "used by several persons, with shared slides amongst the decks.",
+    chain=True,
 )
 
 
